| Title: | Country boundaries at high resolution. |
|---|---|
| Description: | High resolution vector country boundaries derived from Natural Earth data, can be plotted in rworldmap. |
| Authors: | Andy South |
| Maintainer: | Andy South <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.01 |
| Built: | 2026-05-15 06:16:20 UTC |
| Source: | https://github.com/andysouth/rworldxtra |
Enables mapping of country level and gridded user datasets by facilitating joining to world maps and visualisation options.
| Package: | rworldxtra |
| Type: | Package |
| Version: | 1.01 |
| Date: | 2012-10-1 |
| License: | GPL (>= 2) |
Version 1.01 newly uses updated Natural Earth Data for country boundaries.
Andy South
Maintainer: <[email protected]>
Derived from : http://www.naturalearthdata.com/downloads/10m-cultural-vectors/
data(countriesHigh)data(countriesHigh)
A 'SpatialPolygonsDataFrame' [package "sp"] object containing country boundaries derived from Natural Earth data. Polygons are attributed with country codes.
data(countriesHigh)data(countriesHigh)
The format is: Formal class 'SpatialPolygonsDataFrame' [package "sp"] with 5 slots
Derived fron version 1.4.0 of Natural Earth data 1:10 m data.
The different country boundaries in rworldmap are processed from Natural Earth Data as follows :
All :
~ rename any non-ASCII country names that cause R trouble
~ rename Curacao which is particularly troublesome !
~ check polygon geometries using checkPolygonsHoles
~ set projections, e.g. proj4string(countriesCoarse) <- CRS("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")
~ set polygon IDs to country names (from ADMIN field)
~ copy ISO_A3 to ISO3
~ replace missing ISO3 codes (6 in this version) with ADM0_A3
~ check for duplicate ISO3 codes (2 in this version)
~ set ISO3 for Gaza to Gaza and 'Ashmore and Cartier Islands' to Ashm
~ replace POP_EST of -99 with NA
~ join on countryRegions data
countriesCoarseLessIslands : ne_110
countriesCoarse : ne_110 plus extra countries from ne_50 plus Tuvalu from ne_10
countriesLow : ne_50 plus Tuvalu from ne_10
countriesHigh (in package rworldxtra) : ne_10
http://www.naturalearthdata.com/downloads/10m-cultural-vectors/
data(countriesHigh)data(countriesHigh)